
/**********************************************************************************
 Persistence of Vision Ray Tracer Scene Description File
 File name   : LMmyowntest.pov
 Version     : 3.6 / MegaPOV 1.0
 Description : Test file for LawnMaker 1.2 by Uwe Glei
               
 Date        : November 2004
 Author      : Thomas A. M. de Groot
 E-mail      : t.degroot@inter.nl.net
 
 Copyright (C) 2004. All rights reserved.
**********************************************************************************/

/*
--------------------------------------------------------------------------------
Examplefile to show usage of LawnMaker 1.2

--------------------------------------------------------------------------------
*/

#include "rand.inc"

#include "lawnmaker.inc"
#include "Halm1.inc"

#version 3.5;

global_settings {
  assumed_gamma 1.0
  max_trace_level 5
}
background { color rgb 1 }

#declare HFscale = <18,0.1,41>;
#declare HF =
#difference {
height_field {
  png "WildGrass_2_UR_512_Height.png"
  texture {
    pigment {
      image_map { png "WildGrass_2_UR_512_Height.png" map_type 0 interpolate 2 once }
      rotate x*90 // lay X-Y image map down onto X-Z height field plane
    }
  }
	translate <-.5, 0, -.5>
  scale HFscale
}
box { <-5, -1, 1.5>, <5, 1, 18.5> pigment{ rgb <0,0,0>}}
plane { y, -0.5 pigment{ rgb <0,0,0>}}
}

// Only the necessary values are changed
//#declare LawnStart = <-9, -20.5>;
//#declare LawnStop  = < 9,  20.5>;
#declare LawnStart = <-1, -1>;
#declare LawnStop  = < 1,  1>;
#declare LawnStepX = <0.1, 0.1>;
#declare LawnStepZ = <0.1, 0.1>;

#declare LawnSurface = object {HF};

//#declare LawnHeight = pigment { image_map { png "RidgedFractal1.png"} rotate <90,0,0> scale HFscale }

//#declare LawnPosStretch = 1;
//#declare LawnPosition = pigment { image_map { png "RidgedFractal1.png"} rotate <90,0,0> scale HFscale }

// New coloring used for the straws
#declare LawnColor[4] =
  pigment { spotted turbulence 2  scale 0.5
            colour_map { [0.0 color rgb <0.95, 0.7, 0.25>]
                         [1.0 color rgb <0.9, 0.8, 0.3>] }
          }
 

//to save space below:
//#declare h = <0.2,0.2,0.5>;

#declare T = 6;
#declare TypeGeometry = array[T] { Blade1,     Blade2,      Blade3,    Blade4,    Blade5,    Halm1   }
#declare TypeWeight   = array[T] { 4,          4,           4,         3,         3,         0.2     }
#declare TypeSize1    = array[T] { <.7,.6,.7>, <.7,.5,.7>,  <.6,.4,.6>,<.6,.4,.6>,<.6,.4,.6>,<2,2,2> }
#declare TypeSize2    = array[T] { <1,1.5,1>,  <1,1.4,1>,   <1,1.2,1>, <1,1.1,1>, <1,1.1,1>, <3,3,3> }
#declare TypeColMap   = array[T] { 1,          1,           2,         2,         2,         4       }
#declare TypeTurn     = array[T] { <0, 360>,   <0, 360>,    <0, 360>,  <0, 360>,  <0, 360>,  <0, 360>}
#declare TypeIncline  = array[T] { <0, 50>,    <0, 30>,     <0, 10>,    <0,5>,    <-2,2>,    <-5,5>  }

// invoking LawnMaker and thus actually producing the grass
LawnMaker()
//object {GrassPatch}
//object {GrassPatch translate 2*x}

// -------- Placing the GrassPatches -------------

#declare Seed=seed(2);
#declare Seed2=seed(1);
#declare Spacing = 2.0;
#declare Cnt = 0;


#declare PosX = -2;

#while (PosX < 2)

  #declare PosZ = -4;

  #while (PosZ < 4)

    // trace function
    #declare Norm = <0, 0, 0>;
    //#declare Start = <PosX+(rand(Seed)-0.5)*Spacing, UpperBound+1, PosZ+(rand(Seed2)-0.5)*Spacing>;
    #declare Start = <PosX, 5, PosZ>;
   #declare Pos = trace (
                          HF,     	 // object to test
                          Start,           // starting point
                          -y,              // direction
                          Norm );          // normal
    #if (Norm.x != 0 | Norm.y != 0 | Norm.z != 0)   // if intersection is found, normal differs from 0
        object {
          GrassPatch
          scale RRand(0.99, 1.01, Seed)
          //rotate RRand(0, 360, Seed2)*y
          translate Pos
        }
        #declare Cnt = Cnt+1;
      //#end
    #end

    #declare PosZ = PosZ+Spacing;

  #end

  #declare PosX = PosX+Spacing;
#end
#debug concat("Placed ", str(Cnt,0,0), " patches\n")

//===================================================================================================================================
camera { 
  location  <0, 10, -20> 
  direction 1.5*z
  right x*image_width/image_height  
  look_at   <0.0, 0.0,  0.0>
}

light_source {
  <-30, 30, -30>            
  color rgb <1, 1, 1>  
}

/*

#declare Landtex =
pigment {
  #if (Slope)
    slope {<0.0, SlopeValue, 0.0>, 0.0, 0.5					// slope
      altitude <0.0, 1-SlopeValue, 0.0>, 0.0, 1.5   // altitude 
      // note: put both slope and altitude ranges to 0 and 1, and you get a kind of water edge with algae
    }
  #else
    gradient y
  #end
  colour_map {
    [0.00 rgb <0.1,0.4,0.1>]
    [0.25 rgb <0.5,0.4,0.3>]
    [0.50 rgb 0.50]
    [0.75 rgb 0.75]
    [1.00 rgb 0.90]
  }
}

#declare Landscape =
height_field {
	tga "LunarMare.tga"
	smooth
	pigment {Landtex}
	//translate <-.5, 0.000, -.5>
	//scale 600
	//rotate 225*y
	//translate <40, -3.11, -240>
}

object {Landscape}
*/


object {HF}

// floor with a little mound
/*  plane {  y, 0 
    texture { pigment { bozo
                        color_map { [0, color rgb <0.3,0.2,0>]
                                    [1, color rgb <0.25,0.05,0>] } }
              finish { diffuse 0.8  ambient 0.1 }
    }
  }  
*/

// axes:
union {
cylinder { <-5, 0, 0>, <5, 0, 0>, 0.1 }
cylinder { <0, -5, 0>, <0, 5, 0>, 0.1 }
cylinder { <0, 0, -5>, <0, 0, 5>, 0.1 }
pigment {rgb <1,0,0>}
}